@@ -492,7 +492,7 @@ class Action(MethodsInterface):
                 val = self.eachvar
             else:
                 val = dv.Get(var)
-            if type(val) == list:
+            if type(val) in (list, tuple):
                 val = ",".join(val)
             if func:
                 if hasattr(tt, func):
