@@ -388,12 +388,13 @@ def display_error(error, args, groups):
                         if (getattr(args, field.name) == "list" and
                                     "choice" in field.type):
                             if error.field_obj:
+                                field_obj = FieldAdapter.from_detect(error.field_obj)
                                 list_answer = True
-                                varname = (error.field_obj.label or
-                                           error.field_obj.name)
-                                comments = error.field_obj.comments
-                                values = error.field_obj.choice
-                                value = error.field_obj.value
+                                varname = (field_obj.label or
+                                           field_obj.name)
+                                comments = field_obj.comments
+                                values = field_obj.choice
+                                value = field_obj.value
                                 list_value = error.field_obj.listvalue or []
                         params_text += getErrorOnParam(args, field)
                     else:
